*********
Chang-log
*********

v0.4.0
======

*   Gsub: Adding serial option to wait until the previous job to finish.

v0.3.1
======

*   Updating formatting (of code and of docs)
*   Adding command-line tools to autodoc

v0.3.0
======

*   Gsub: adding status using YAML-file, allowing submit from YAML-file (#24)

v0.2.0
======

*   Bugfix: implementing --no-header options
*   Adding delay to Gsub
*   Adding tip to build once (using hardware optimization) (#22)
*   Updating gitignore
